detected.genes
A data.frame containing information on the detected genes. This includes the posterior estimate, variance, and upper bound of the prediction interval fo all genes. Other gene level information that is included is the gene location including chromosome a
lmer.out
A mer object containing all of the model output information, including parameter estimates, from the lmer function.