Learn R Programming

MixMAP (version 1.2)

Plot: Plot

Description

The purpose of plot is to graphically display the results of MixMAP in a similar way as a Manhattan plot that is used for Genome Wide Association Studies.

Usage

## S3 method for class 'MixMAP':
plot(x,col.genes=c("black","gray"),col.detected=c("blue","violet"),
  col.text="black",title="MixMAP Manhattan Plot",display.text=TRUE)

Arguments

x
An object of class mixmap, which is output from the function MixMAP.
col.genes
A character vector containing colors for alternate chromosomes. Default is black and gray.
col.detected
A character vector containing with the names of color to display genes detected by MixMAP. Genes detected by MixMAP but not by single SNP analysis will be dispalyed using the first color. Genes deteced in both MixMAP and single SNP analysis are displaye
col.text
A character string with the name of a color to display text of the names of detected genes. Default is black.
title
A character string used a title for the MixManhattan plot. Default is "MixMAP Manhattan Plot".
display.text
Either TRUE or FALSE. FALSE will not label detected genes; TRUE will add text. Default is TRUE.

Value

  • Returns a MixManhattan plot.

Details

Since MixMAP searches for genes with small empirical Bayes estimates, the resulting graph plots all genes with a positive empirical Bayes estimate as zero, and genes with a negative Bayes estimate are displayed as their absolute values.

References

Foulkes, A.S., Matthews, G.J., Das, U., Ferguson, J., Reilly, M. (2013) ``Mixed Modeling of Meta-Analysis P-Values (MixMAP) Suggests Multiple Novel Gene Loci for Low Density Lipoprotein Cholesterol". PLoS ONE 8(2): e54812.

Examples

Run this code
data(MixMAP_example)
#Run MixMAP
MixOut<-MixMAP(MixMAP_example,pval="GC.Pvalue",snp="MarkerName",
  chr="Chr",coord="Coordinate",gene="Gene")
plot(MixOut)

Run the code above in your browser using DataLab