Learn R Programming

MixMAP (version 1.2)

Summary: Summary

Description

Displays a summary of the MixMAP object.

Usage

## S3 method for class 'MixMAP':
summary(mixmap.object)

Arguments

mixmap.object
An object of class MixMAP, which is output from the function MixMAP.

Value

  • Returns a summary of the MixMAP object.

Details

This method returns up to the top ten detected genes as well as information on the total number of genes and the number of genes detected.

References

Foulkes, A.S., Matthews, G.J., Das, U., Ferguson, J., Reilly, M. (2013) ``Mixed Modeling of Meta-Analysis P-Values (MixMAP) Suggests Multiple Novel Gene Loci for Low Density Lipoprotein Cholesterol". PLoS ONE 8(2): e54812.

Examples

Run this code
data(MixMAP_example)
#Run MixMAP
MixOut<-MixMAP(MixMAP_example,pval="GC.Pvalue",snp="MarkerName",
  chr="Chr",coord="Coordinate",gene="Gene")
summary(MixOut)

Run the code above in your browser using DataLab